SystemOrganization addCategory: #'Pier-Math'!

!PRViewRenderer methodsFor: '*pier-math-visiting' stamp: 'cdlm 11/19/2007 22:47'!
visitMathText: anObject
	html image form: anObject image; altText: anObject text; class: 'math'! !

!PRVisitor methodsFor: '*pier-math-visiting' stamp: 'lr 5/1/2007 20:38'!
visitMathText: anObject
	self visitText: anObject! !

PRText subclass: #PMMathText
	instanceVariableNames: 'image'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Pier-Math'!

PMMathText class
	instanceVariableNames: 'latex dvipng'!

PMMathText class
	instanceVariableNames: 'latex dvipng'!

!PMMathText class methodsFor: 'accessing' stamp: 'cdlm 11/18/2007 19:36'!
dvipng
	^ dvipng! !

!PMMathText class methodsFor: 'accessing' stamp: 'cdlm 11/18/2007 19:31'!
dvipng: aString
	"Set the path to your ==dvipng== executable"
	dvipng := aString! !

!PMMathText class methodsFor: 'initialization' stamp: 'cdlm 11/18/2007 19:28'!
initialize
	PRDocumentParser textMatcher at: self markup put: self.
	latex := '/usr/texbin/latex'.
	dvipng := '/usr/texbin/dvipng'! !

!PMMathText class methodsFor: 'accessing' stamp: 'cdlm 11/18/2007 19:37'!
latex
	^ latex! !

!PMMathText class methodsFor: 'accessing' stamp: 'cdlm 11/18/2007 19:32'!
latex: aString
	"Set the path to your ==latex== or ==pdflatex== executable."
	latex := aString! !

!PMMathText class methodsFor: 'accessing' stamp: 'lr 11/13/2007 10:21'!
markup
	^ '$$'! !

!PMMathText class methodsFor: 'instance-creation' stamp: 'lr 5/1/2007 20:42'!
parse: aString with: aParser
	^ self content: (aString copyFrom: self markup size + 1 to: aString size - self markup size)! !

!PMMathText class methodsFor: 'initialization' stamp: 'lr 5/1/2007 20:36'!
unload
	PRDocumentParser textMatcher removeKey: self markup ifAbsent: [ ]! !

!PMMathText methodsFor: 'visiting' stamp: 'lr 5/1/2007 20:37'!
accept: aVisitor
	aVisitor visitMathText: self! !

!PMMathText methodsFor: 'private' stamp: 'lr 2/10/2008 22:54'!
buildImage
	| fullname stream latexCommand dvipngCommand |
	[ fullname := self directory fullNameFor: self filename.
	[ stream := FileStream forceNewFileNamed: fullname , '.tex'.
	[ stream nextPutAll: self preamble; nextPutAll: self text; nextPutAll: self postscript ]
		ensure: [ stream close ].
	latexCommand := self latex , ' -output-directory=' , self directory fullName printString , ' -output-format=dvi ' , (fullname , '.tex') printString.
	dvipngCommand := self dvipng , ' -gamma 1.5 -D 120 -bg Transparent -T tight --strict ' , (fullname , '.dvi') printString , ' -o ' , (fullname , '.png') printString.
	OSProcess waitForCommand: latexCommand , ' >/dev/null'.
	OSProcess waitForCommand: dvipngCommand , ' >/dev/null 2>/dev/null'.
	stream := FileStream oldFileNamed: fullname , '.png'.
	^ [ MIMEDocument contentType: 'image/png' content: (stream binary; contents) ] 
		ensure: [ stream close ] ] 
		ensure: [
			self directory
				deleteFileNamed: self filename , '.tex';
				deleteFileNamed: self filename , '.dvi';
				deleteFileNamed: self filename , '.aux';
				deleteFileNamed: self filename , '.log';
				deleteFileNamed: self filename , '.png' ] ]
		ifError: [ :err | ^ err asDisplayText form asMIMEDocument ]! !

!PMMathText methodsFor: 'configuration' stamp: 'cdlm 11/18/2007 16:09'!
directory
	^ (FileDirectory default directoryNamed: 'pier-math') assureExistence! !

!PMMathText methodsFor: 'configuration' stamp: 'cdlm 11/18/2007 19:34'!
dvipng
	^ self class dvipng! !

!PMMathText methodsFor: 'configuration' stamp: 'cdlm 11/18/2007 19:35'!
filename
	^ self hash asString! !

!PMMathText methodsFor: 'accessing' stamp: 'lr 11/13/2007 10:52'!
image
	"Answer a cached mime document of the receivers image."
	
	^ image ifNil: [ image := self buildImage ]! !

!PMMathText methodsFor: 'configuration' stamp: 'cdlm 11/18/2007 19:34'!
latex
	^ self class latex! !

!PMMathText methodsFor: 'configuration' stamp: 'lr 11/13/2007 11:09'!
postscript
	^ '\]
\end{document}'! !

!PMMathText methodsFor: 'configuration' stamp: 'lr 11/13/2007 11:09'!
preamble
	^ '\nonstopmode
\documentclass[12pt]{article}

\usepackage{amsmath}
\usepackage{amsfonts}
\usepackage{amssymb}
\usepackage{ucs}
\usepackage[utf8x]{inputenc}
\usepackage[dvips,usenames]{color}
\pagestyle{empty}
\begin{document}
\['! !

!PMMathText methodsFor: 'accessing' stamp: 'lr 11/13/2007 10:51'!
text: aString
	super text: aString.
	image := nil! !

!PRWikiWriter methodsFor: '*pier-math-visiting' stamp: 'lr 11/13/2007 10:27'!
visitMathText: anObject
	self 
		nextPutAll: anObject class markup; 
		nextPutAll: anObject text;
		nextPutAll: anObject class markup! !
PMMathText initialize!
